"""
PyAnsys Tools Report version module.

Module containing the version function for .
"""
try:
    import importlib.metadata as importlib_metadata
except ModuleNotFoundError:
    import importlib_metadata

__version__ = importlib_metadata.version("pyansys-tools-report")


def version():
    """Return the version of the PyAnsys Report Tool.

    Returns
    -------
    str
        The version of the tool being used.
    """
    return __version__



"""PyAnsys Tools Report package."""

# Improving accessibility to the pyansys-tools-report resources

from ansys.tools.report._version import __version__, version
from ansys.tools.report.report import Report
